@@ -33,7 +33,7 @@ module Graphics.UI.GLUT.Window (
    -- * Changing the window geometry
 
    -- $ChangingTheWindowGeometry
-   windowPosition, windowSize, fullScreen,
+   windowPosition, windowSize, fullScreen, fullScreenToggle,
 
    -- * Manipulating the stacking order
 
@@ -71,11 +71,16 @@ import Graphics.UI.GLUT.Constants (
    glut_CURSOR_BOTTOM_RIGHT_CORNER, glut_CURSOR_BOTTOM_LEFT_CORNER,
    glut_CURSOR_INHERIT, glut_CURSOR_NONE, glut_CURSOR_FULL_CROSSHAIR,
    glut_WINDOW_CURSOR )
+import Graphics.UI.GLUT.Extensions
 import Graphics.UI.GLUT.QueryUtils ( simpleGet )
 import Graphics.UI.GLUT.Types ( Window, makeWindow )
 
 --------------------------------------------------------------------------------
 
+#include "HsGLUTExt.h"
+
+--------------------------------------------------------------------------------
+
 -- $CreatingAndDestroyingSubWindows
 -- Each created window has a unique associated OpenGL context. State changes to
 -- a window\'s associated OpenGL context can be done immediately after the
@@ -319,6 +324,15 @@ foreign import CALLCONV unsafe "glutFullScreen" fullScreen :: IO ()
 
 --------------------------------------------------------------------------------
 
+-- | (/freeglut only/) Toggle between windowed and full screen mode.
+
+fullScreenToggle :: IO ()
+fullScreenToggle = glutFullScreenToggle
+
+EXTENSION_ENTRY(unsafe,"freeglut",glutFullScreenToggle,IO ())
+
+--------------------------------------------------------------------------------
+
 -- $ManipulatingTheStackingOrder
 -- 'pushWindow' and 'popWindow' work on both top-level windows and subwindows.
 -- The effect of pushing and popping windows does not take place immediately.
